.. image:: https://img.shields.io/pypi/v/split_dataset.svg
        :target: https://pypi.python.org/pypi/split_dataset

.. image:: https://img.shields.io/travis/portugueslab/split_dataset.svg
        :target: https://travis-ci.com/portugueslab/split_dataset

.. image:: https://codecov.io/gh/portugueslab/split_dataset/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/portugueslab/split_dataset

.. image:: https://pyup.io/repos/github/portugueslab/split_dataset/shield.svg
     :target: https://pyup.io/repos/github/portugueslab/split_dataset/
     :alt: Updates



A package for HDF5-based chunked arrays used by Fimpy.

This package has been developed in the `Portugues lab`_. For the documentation,
visit https://portugueslab.github.io/split_dataset

Features
--------

* TODO

Credits
-------

The package was created with Cookiecutter_ and this_ template.

.. _`Portugues lab`: http://www.portugueslab.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _this: https://github.com/audreyr/cookiecutter-pypackage
